@@ -2,3 +2,6 @@
 #' @importFrom lifecycle deprecate_soft
 ## usethis namespace: end
 NULL
+
+#' @noRd
+.pkgenv <- rlang::env()
